// License: GPLv2+
const { __ } = wp.i18n;

var el = wp.element.createElement,
	registerBlockType = wp.blocks.registerBlockType,
	ServerSideRender = wp.components.ServerSideRender,
	TextControl = wp.components.TextControl,
    SelectControl = wp.components.SelectControl,
	RadioControl = wp.components.RadioControl,
	CheckboxControl = wp.components.CheckboxControl,
	InspectorControls = wp.editor.InspectorControls;

const churchAdminIcon = el('svg', { width: 30, height: 30 ,viewBox:"0 0 30 30"},
  el('path', { d:"M632.639 161.655v336.836h-62.114V125.796L787.932.277l217.408 125.519v372.695H756.873V312.147h-62.117v-62.116h62.117v-62.118h62.117v62.118h62.117v62.116H818.99v124.228h124.235v-274.72L787.932 72.004l-155.293 89.651z",transform:"matrix(.05904 0 0 .05022 -31.936 2.274)",fill:"#F7931D"
         } ));

    
/*
 * Here's where we register the block in JavaScript.
 *
 * It's not yet possible to register a block entirely without JavaScript, but
 * that is something I'd love to see happen. This is a barebones example
 * of registering the block, and giving the basic ability to edit the block
 * attributes. (In this case, there's only one attribute, 'foo'.)
 */
registerBlockType( 'church-admin/sermon-series', {
	title: __('Church Admin Sermon Series'),
	icon: churchAdminIcon,
	category:'church-admin',
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log('Attributes:'+props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/sermon-series',
				attributes: props.attributes,
			} ),
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Columns','church-admin'),
					value: props.attributes.cols,
					onChange: ( value ) => { props.setAttributes( { cols: value } ); },
				} ),
			   el( TextControl, {
					label: __('Sermon Page URL','church-admin'),
					value: props.attributes.sermon_page,
					onChange: ( value ) => { props.setAttributes( { sermon_page: value } ); },
				} ),
			   
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/sermon-podcast', {
	title: __('Church Admin Sermon Podcast'),
	icon: churchAdminIcon,
	category:'church-admin',
    
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log('Attributes:'+props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/sermon-podcast',
				attributes: props.attributes,
			} ),
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Limit to Series Name','church-admin'),
					value: props.attributes.series_name,
					onChange: ( value ) => { props.setAttributes( { series_name: value } ); },
				} ),
			   el( TextControl, {
					label: __('One sermon only - Sermon title','church-admin'),
					value: props.attributes.sermon_title,
					onChange: ( value ) => { props.setAttributes( { sermon_title: value } ); },
				} ),
			   el( TextControl, {
					label: __('Order By','church-admin'),
					value: props.attributes.order,
					onChange: ( value ) => { props.setAttributes( { order: value } ); },
				} ),
			   el( TextControl, {
					label: __('Exclude sections','church-admin'),
					value: props.attributes.exclude,
					onChange: ( value ) => { props.setAttributes( { exclude: value } ); },
				} ),
               el( TextControl, {
					label: __('How many to show','church-admin'),
					value: props.attributes.howmany,
					onChange: ( value ) => { props.setAttributes( { howmany: value } ); },
				} ),
			   el( CheckboxControl, {
					label: __('Show most popular'),
					value: props.attributes.most_popular,
					checked: props.attributes.most_popular,
					onChange: ( value ) => { props.setAttributes( { most_popular: value } ); },
				} )
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
//register
registerBlockType( 'church-admin/register', {
	title: __('Church Admin Register'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/register',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Which member type to save as'),
					value: props.attributes.member_type_id,
					onChange: ( value ) => { props.setAttributes( { member_type_id: value } ); },
				} ),
				el( CheckboxControl, {
					label: __('Create user'),
					value: props.attributes.create_user,
					checked: props.attributes.create_user,
					onChange: ( value ) => { props.setAttributes( { create_user: value } ); },
				} )
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
//rota
registerBlockType( 'church-admin/rota', {
	title: __('Church Admin Schedule'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/rota',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Which service_id?'),
					value: props.attributes.service_id,
					onChange: ( value ) => { props.setAttributes( { service_id: value } ); },
				} ),
				el( TextControl, {
					label: __('How many weeks to show?'),
					value: props.attributes.weeks,
					onChange: ( value ) => { props.setAttributes( { weeks: value } ); },
				} ),
               el( TextControl, {
					label: __('Title'),
					value: props.attributes.title,
					onChange: ( value ) => { props.setAttributes( { title: value } ); },
				} ),
				el( CheckboxControl, {
					label: __('Require Login?'),
					value: props.attributes.logged_in,
					checked: props.attributes.logged_in,
					onChange: ( value ) => { props.setAttributes( { logged_in: value } ); },
				} ),
               el( CheckboxControl, {
					label: __('Initials?'),
					value: props.attributes.initials,
					checked: props.attributes.initials,
					onChange: ( value ) => { props.setAttributes( { initials: value } ); },
				} )
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
//small groups
registerBlockType( 'church-admin/small-groups-list', {
	title: __('Church Admin Small Groups'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/small-groups-list',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				el( CheckboxControl, {
					label: __('Show map?'),
					value: props.attributes.map,
					checked: props.attributes.map,
					onChange: ( value ) => { props.setAttributes( { map: value } ); },
				} ),
				el( TextControl, {
					label: __('Map zoom level?'),
					value: props.attributes.zoom,
					onChange: ( value ) => { props.setAttributes( { zoom: value } ); },
				} ),
			   el( CheckboxControl, {
					label: __('Photo Style?'),
					value: props.attributes.photo,
					checked: props.attributes.photo,
					onChange: ( value ) => { props.setAttributes( { photo: value } ); },
				} ),
			   el( CheckboxControl, {
					label: __('Logged in?'),
					value: props.attributes.loggedin,
					value: props.attributes.loggedinadd,
					checked: props.attributes.loggedin,
					onChange: ( value ) => { props.setAttributes( { loggedin: value } ); },
				} ),
			   el( CheckboxControl, {
					label: __('PDF link?'),
					value: props.attributes.pdf,
					
					checked: props.attributes.pdf,
					onChange: ( value ) => { props.setAttributes( { pdf: value } ); },
				} ),
			   el( TextControl, {
					label: __('Title for PDF'),
					value: props.attributes.title,
					onChange: ( value ) => { props.setAttributes( { title: value } ); },
				} )
				
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
//small group signup
registerBlockType( 'church-admin/small-groups-signup', {
	title: __('Church Admin Small Groups Sign Up'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/small-groups-signup',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				
				el( TextControl, {
					label: __('People Types (Adult, Children, Teenagers?'),
					value: props.attributes.people_types,
					onChange: ( value ) => { props.setAttributes( { people_types: value } ); },
				} ),
			   
			   el( TextControl, {
					label: __('Title for Signup'),
					value: props.attributes.title,
					onChange: ( value ) => { props.setAttributes( { title: value } ); },
				} )
				
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
//small groups
registerBlockType( 'church-admin/small-group-members', {
	title: __('Church Admin Small Group Members'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/small-group-members',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				el( CheckboxControl, {
					label: __('Show map?'),
					value: props.attributes.map,
					onChange: ( value ) => { props.setAttributes( { map: value } ); },
				} ),
				el( TextControl, {
					label: __('Map zoom level?'),
					value: props.attributes.zoom,
					onChange: ( value ) => { props.setAttributes( { zoom: value } ); },
				} ),
				
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
//address list
registerBlockType( 'church-admin/address-list', {
	title: __('Church Admin Address List'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/address-list',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				
				el( TextControl, {
					label: __('Which member types?'),
					value: props.attributes.member_type_id,
					onChange: ( value ) => { props.setAttributes( { member_type_id: value } ); },
				} ),
				el( TextControl, {
					label: __('Which Site id?'),
					value: props.attributes.site_id,
					onChange: ( value ) => { props.setAttributes( { site_id: value } ); },
				} ),
			   el( CheckboxControl, {
					label: __('PDF links?'),
					value: props.attributes.pdf,
					onChange: ( value ) => { props.setAttributes( { pdf: value } ); },
                    checked: props.attributes.pdf
				} ),
               el( CheckboxControl, {
					label: __('VCF link?'),
					value: props.attributes.vcf,
                    onChange: ( value ) => {
									props.setAttributes( { vcf: value } );
								},
                    checked: props.attributes.vcf
					
				} ),
				el( CheckboxControl, {
					label: __('Require Login?'),
					value: props.attributes.logged_in,
					checked: props.attributes.logged_in,
					onChange: ( value ) => { props.setAttributes( { logged_in: value } ); },
				} ),
				el( CheckboxControl, {
					label: __('Show maps?'),
					value: props.attributes.map,
					checked: props.attributes.map,
					onChange: ( value ) => { props.setAttributes( { map: value } ); },
				} ),
				el( CheckboxControl, {
					label: __('Show kids?'),
					value: props.attributes.kids,
					checked: props.attributes.kids,
					onChange: ( value ) => { props.setAttributes( { kids: value } ); },
				} ),
				
				el( CheckboxControl, {
					label: __('Updateable?'),
					value: props.attributes.updateable,
					checked: props.attributes.updateable,
					onChange: ( value ) => { props.setAttributes( { updateable: value } ); },
				} )
				
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );

registerBlockType( 'church-admin/serving', {
	title: __('Church Admin Serving Request'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/serving',
				attributes: props.attributes,
			} ),
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			/*el( InspectorControls, {},
				el( TextControl, {
					label: 'Foo',
					value: props.attributes.foo,
					onChange: ( value ) => { props.setAttributes( { foo: value } ); },
				} )
			),*/
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );


registerBlockType( 'church-admin/sessions', {
	title: __('Church Admin Sessions'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/sessions',
				attributes: props.attributes,
			} )

		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );

registerBlockType( 'church-admin/recent', {
	title: __('Church Admin Recent Directory activity'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/recent',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				el( TextControl, {
					label: __('How many weeks?'),
					value: props.attributes.weeks,
					onChange: ( value ) => { props.setAttributes( { weeks: value } ); },
				} )
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/calendar', {
	title: __('Church Admin Calendar'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/calendar',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				el( CheckboxControl, {
					label: __('Table Style?'),
					value: props.attributes.style,
					onChange: ( value ) => { props.setAttributes( { style: value } ); },
				} )
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/video-embed', {
	title: __('Church Admin Video Embed'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/video-embed',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Video share url?'),
					value: props.attributes.url,
					onChange: ( value ) => { props.setAttributes( { url: value } ); },
				} ),
				
				el( CheckboxControl, {
					label: __('Show number of views?'),
					value: props.attributes.show_views,
					checked: props.attributes.show_views,
					onChange: ( value ) => { props.setAttributes( { show_views: value } ); },
				} ),
               el( SelectControl, {
                    label: __( 'Page Alignment (will adjust on live site!)' ),
                    value: props.attributes.container,
                    onChange: ( value ) => { props.setAttributes( { container: value } ); },
                    options: [
                        { value: 'aligncenter', label: __( 'Centered' ) },    
                      { value: 'alignwide', label: __( 'Wide' ) },
                      { value: 'alignfull', label: __( 'Full width' ) },
                    ],
                }),
			)
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/ministries', {
	title: __('Church Admin Ministries'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/ministries',
				attributes: props.attributes,
			} ),
			
			/*
			 * InspectorControls lets you add controls to the Block sidebar. In this case,
			 * we're adding a TextControl, which lets us edit the 'foo' attribute (which
			 * we defined in the PHP). The onChange property is a little bit of magic to tell
			 * the block editor to update the value of our 'foo' property, and to re-render
			 * the block.
			 */
			 
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Member Types?'),
					value: props.attributes.member_type_id,
					onChange: ( value ) => { props.setAttributes( { member_type_id: value } ); },
				} )
			),
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Ministry ids?'),
					value: props.attributes.ministry_id,
					onChange: ( value ) => { props.setAttributes( { ministry_id: value } ); },
				} )
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/my-rota', {
	title: __('Church Admin My Rota'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/my-rota',
				attributes: props.attributes,
			} ),
			
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/attendance', {
	title: __('Church Admin Attendance'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/attendance',
				attributes: props.attributes,
			} ),
			
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/giving', {
	title: __('Church Admin Giving'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/giving',
				attributes: props.attributes,
			} ),
			
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/pledges', {
	title: __('Church Admin Pledges'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/pledges',
				attributes: props.attributes,
			} ),
			
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/volunteer', {
	title: __('Church Admin Volunteer'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/volunteer',
				attributes: props.attributes,
			} ),
			
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/graph', {
	title: __('Church Admin Graph'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/graph',
				attributes: props.attributes,
			} ),
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Width in pixels'),
					value: props.attributes.width,
					onChange: ( value ) => { props.setAttributes( { width: value } ); },
				} )
			),
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Height in pixels'),
					value: props.attributes.height,
					onChange: ( value ) => { props.setAttributes( { height: value } ); },
				} )
			),			
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );

registerBlockType( 'church-admin/birthdays', {
	title: __('Church Admin Birthdays'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		console.log(props.attributes);
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/birthdays',
				attributes: props.attributes,
			} ),
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Member Types'),
					value: props.attributes.member_type_id,
					onChange: ( value ) => { props.setAttributes( { member_type_id: value } ); },
				} )
			),
			el( InspectorControls, {},
				el( TextControl, {
					label: __('People Types'),
					value: props.attributes.people_type_id,
					onChange: ( value ) => { props.setAttributes( { people_type_id: value } ); },
				} )
			),
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Days to show'),
					value: props.attributes.days,
					onChange: ( value ) => { props.setAttributes( { days: value } ); },
				} )
			),
            el( CheckboxControl, {
					label: __('Show age'),
					value: props.attributes.show_age,
					checked: props.attributes.show_age,
					onChange: ( value ) => { props.setAttributes( { show_age: value } ); },
				} )
		];
	},
	

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
registerBlockType( 'church-admin/member-map', {
	title: __('Church Admin Member Map'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/member-map',
				attributes: props.attributes,
				show_in_rest:true
			} ),
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Member Types'),
					value: props.attributes.member_type_id,
					onChange: ( value ) => { props.setAttributes( { member_type_id: value } ); },
				} )
			),
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Zoom'),
					value: props.attributes.zoom,
					onChange: ( value ) => { props.setAttributes( { zoom: value } ); },
				} )
			),	
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Width'),
					value: props.attributes.width,
					onChange: ( value ) => { props.setAttributes( { width: value } ); },
				} )
			),
			el( InspectorControls, {},
				el( TextControl, {
					label: __('Height'),
					value: props.attributes.height,
					onChange: ( value ) => { props.setAttributes( { height: value } ); },
				} )
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );
//rota
registerBlockType( 'church-admin/service-booking', {
	title: __('Church Admin Service Booking'),
	icon: churchAdminIcon,
	category:'church-admin',
   
	/*
	 * In most other blocks, you'd see an 'attributes' property being defined here.
	 * We've defined attributes in the PHP, that information is automatically sent
	 * to the block editor, so we don't need to redefine it here.
	 */

	edit: function( props ) {
		
		return [
			/*
			 * The ServerSideRender element uses the REST API to automatically call
			 * php_block_render() in your PHP code whenever it needs to get an updated
			 * view of the block.
			 */
			el( ServerSideRender, {
				block: 'church-admin/service-booking',
				attributes: props.attributes,
			} ),
			
            el( InspectorControls, {},
				el( TextControl, {
					label: __('Which service_id?'),
					value: props.attributes.service_id,
					onChange: ( value ) => { props.setAttributes( { service_id: value } ); },
				} ),
				el( TextControl, {
					label: __('How many days to show?'),
					value: props.attributes.days,
					onChange: ( value ) => { props.setAttributes( { days: value } ); },
				} ),
               el( TextControl, {
					label: __('Admin Emails'),
					value: props.attributes.admin_email,
					onChange: ( value ) => { props.setAttributes( { admin_email_address: value } ); },
				} ),
				el( TextControl, {
					label: __('Max people per booking'),
					value: props.attributes.max_fields,
					onChange: ( value ) => { props.setAttributes( { max_fields: value } ); },
				} ),
               el( SelectControl, {
                    label: __( 'Booking mode' ),
                    value: props.attributes.booking_mode,
                    onChange: ( value ) => { props.setAttributes( { booking_mode: value } ); },
                    options: [
                        { value: 'bubbles', label: __( 'Bubbles' ) },    
                      { value: 'individuals', label: __( 'Individuals' ) }
                     
                    ],
                }),
			),
		];
	},

	// We're going to be rendering in PHP, so save() can just return null.
	save: function() {
		return null;
	},
} );